# collectiondict - Create multidicts more easily

This package simplifies the creation of dictionaries which collect a stream of
key-value-pairs into a dictionaries of containers. It is conceptunally similar
to [multidict](https://pypi.org/project/multidict/) but much broader with
respect to the supported types.
